==> 0.0.1.tar.gz: ios/Classes/AlicloudImpinteractionClassroomPlugin.m <==
#import "AlicloudImpinteractionClassroomPlugin.h"

#import "AIRBDEnvironments.h"
#import <AliStandardClassroomBundle/AliStandardClassroomBundle.h>
#import "AIRBDClassroomStudent4iPhoneViewController.h"

#import "AIRBDNavController.h"

@implementation AlicloudImpinteractionClassroomPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"alicloud_impinteraction_classroom"
            binaryMessenger:[registrar messenger]];
  AlicloudImpinteractionClassroomPlugin* instance = [[AlicloudImpinteractionClassroomPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS sth" stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"getBatteryLevel" isEqualToString:call.method]) {
        result([@"iOS battery" stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"init" isEqualToString:call.method]) {
        NSDictionary *param = @{
            @"userId": call.arguments[@"userId"],
            @"appId": call.arguments[@"appId"],
            @"appKey": call.arguments[@"appKey"],
            @"serverHost": call.arguments[@"serverHost"],
            @"serverSecret": call.arguments[@"serverSecret"],
            };
        [self init:param];
        result([@"iOS init" stringByAppendingString:call.arguments[@"userId"]]);
    } else if ([@"setUp" isEqualToString:call.method]) {
        NSDictionary *param = @{
            @"classId": call.arguments[@"classId"],
            };
        [self setUp:param];
        result([@"iOS setUp" stringByAppendingString:call.arguments[@"classId"]]);
    } else {
        result(FlutterMethodNotImplemented);
    }
}

- (void)init: (NSDictionary*) param{
    [AIRBDEnvironments shareInstance]._userId = [param valueForKey:@"userId"];
    [AIRBDEnvironments shareInstance]._appId = [param valueForKey:@"appId"];
    [AIRBDEnvironments shareInstance]._appKey = [param valueForKey:@"appKey"];
    [AIRBDEnvironments shareInstance]._serverHost = [param valueForKey:@"serverHost"];
    [AIRBDEnvironments shareInstance]._serverSecret = [param valueForKey:@"serverSecret"];
}

- (void)setUp: (NSDictionary*) param{
    NSString *classId = [param valueForKey:@"classId"];
    [self navToClassroom:classId];
}

- (void)navToClassroom: (NSString*) classId{
    NSLog(@"nav to classroom:%@", classId);
    
    NSString *userId = [AIRBDEnvironments shareInstance]._userId;
    AIRBDClassroomStudent4iPhoneViewController *vc = [[AIRBDClassroomStudent4iPhoneViewController alloc] initWithUserID:userId userNick:userId classID:classId];
    
    UIWindow *window = [UIApplication sharedApplication].keyWindow;
    UIViewController *windowRootVC = (UIViewController *) window.rootViewController;
    
    AIRBDNavController *navController = [[AIRBDNavController alloc] initWithRootViewController:vc];
    navController.view.backgroundColor = [UIColor clearColor];
    navController.modalPresentationStyle = UIModalPresentationOverCurrentContext;
    navController.navigationBarHidden = YES;
    [windowRootVC presentViewController:navController animated:true completion:nil];
    
    //        // working backup
    //        UINavigationController *mainNav = [[UINavigationController alloc] initWithRootViewController:vc];
    //        mainNav.navigationBarHidden = YES;
    //        mainNav.navigationBar.translucent = NO;
    //        window.rootViewController = mainNav;
    //        window.backgroundColor = [UIColor colorWithWhite:123 alpha:0.3];
    //        [window makeKeyAndVisible];
}

@end

==> 1.8.4.tar.gz: ios/Classes/AlicloudImpinteractionClassroomPlugin.m <==
#import "AlicloudImpinteractionClassroomPlugin.h"

#import "AIRBDEnvironments.h"
#import <AliStandardClassroomBundle/AliStandardClassroomBundle.h>
#import "AIRBDClassroomStudent4iPhoneViewController.h"

#import "AIRBDNavController.h"

@implementation AlicloudImpinteractionClassroomPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"alicloud_impinteraction_classroom"
            binaryMessenger:[registrar messenger]];
  AlicloudImpinteractionClassroomPlugin* instance = [[AlicloudImpinteractionClassroomPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall *)call result:(FlutterResult)result {
    if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS sth" stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"getBatteryLevel" isEqualToString:call.method]) {
        result([@"iOS battery" stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"init" isEqualToString:call.method]) {
        NSDictionary *param = @{
            @"userId": call.arguments[@"userId"],
            @"appId": call.arguments[@"appId"],
            @"appKey": call.arguments[@"appKey4iOS"],
            @"serverHost": call.arguments[@"serverHost"],
            @"serverSecret": call.arguments[@"serverSecret"],
            };
        [self init:param];
        result([@"iOS init" stringByAppendingString:call.arguments[@"userId"]]);
    } else if ([@"setUp" isEqualToString:call.method]) {
        NSDictionary *param = @{
            @"classId": call.arguments[@"classId"],
            };
        [self setUp:param];
        result([@"iOS setUp" stringByAppendingString:call.arguments[@"classId"]]);
    } else {
        result(FlutterMethodNotImplemented);
    }
}

- (void)init: (NSDictionary*) param{
    [AIRBDEnvironments shareInstance]._userId = [param valueForKey:@"userId"];
    [AIRBDEnvironments shareInstance]._appId = [param valueForKey:@"appId"];
    [AIRBDEnvironments shareInstance]._appKey = [param valueForKey:@"appKey"];
    [AIRBDEnvironments shareInstance]._serverHost = [param valueForKey:@"serverHost"];
    [AIRBDEnvironments shareInstance]._serverSecret = [param valueForKey:@"serverSecret"];
}

- (void)setUp: (NSDictionary*) param{
    NSString *classId = [param valueForKey:@"classId"];
    [self navToClassroom:classId];
}

- (void)navToClassroom: (NSString*) classId{
    NSLog(@"nav to classroom:%@", classId);
    
    NSString *userId = [AIRBDEnvironments shareInstance]._userId;
    AIRBDClassroomStudent4iPhoneViewController *vc = [[AIRBDClassroomStudent4iPhoneViewController alloc] initWithUserID:userId userNick:userId classID:classId];
    
    UIWindow *window = [UIApplication sharedApplication].keyWindow;
    UIViewController *windowRootVC = (UIViewController *) window.rootViewController;
    
    AIRBDNavController *navController = [[AIRBDNavController alloc] initWithRootViewController:vc];
    navController.view.backgroundColor = [UIColor clearColor];
    navController.modalPresentationStyle = UIModalPresentationOverCurrentContext;
    navController.navigationBarHidden = YES;
    [windowRootVC presentViewController:navController animated:true completion:nil];
    
    //        // working backup
    //        UINavigationController *mainNav = [[UINavigationController alloc] initWithRootViewController:vc];
    //        mainNav.navigationBarHidden = YES;
    //        mainNav.navigationBar.translucent = NO;
    //        window.rootViewController = mainNav;
    //        window.backgroundColor = [UIColor colorWithWhite:123 alpha:0.3];
    //        [window makeKeyAndVisible];
}

@end
